@@ -50,6 +50,12 @@ class Command(collectstatic.Command):
         processor = self.storage.post_process(self.found_files,
                                               dry_run=self.dry_run)
         for original_path, processed_path, processed in processor:
+            if isinstance(processed, Exception):
+                self.stderr.write("Post-processing '%s' failed!" % original_path)
+                # Add a blank line before the traceback, otherwise it's
+                # too easy to miss the relevant part of the error message.
+                self.stderr.write('')
+                raise processed
             if processed:
                 self.log("Post-processed '%s' as '%s" %
                          (original_path, processed_path), level=1)
